﻿using OrderCriterias;

namespace ManagerInterfaces
{
    /// <summary>
    /// All methods to handle answers
    /// </summary>
    /// <typeparam name="T">a DTO or Entity type answer</typeparam>
    public interface IAnswerManager<T>
    {
        /// <summary>
        /// get the number of T element
        /// </summary>
        /// <returns>the number of T element</returns>
        abstract int getNbElement();
        /// <summary>
        /// get a part of all answers
        /// </summary>
        /// <param name="nb">the actual page</param>
        /// <param name="count">number of T element in a page</param>
        /// <param name="orderCriteria">the order criteria</param>
        /// <returns>
        /// all T element of the database for
        /// this page (or null if (nb-1)*count
        /// is outside boundaries (0, getNbElement()-1)
        /// </returns>
        public IEnumerable<T>? getAnswers(int nb, int count, AnswerOrderCriteria orderCriteria = AnswerOrderCriteria.ById);
        /// <summary>
        /// get a T element with an id
        /// </summary>
        /// <param name="id">the id of the T element</param>
        /// <returns>
        /// the T element that corresponde to
        /// the id or null if there isn't any
        /// </returns>
        public T? getAnswer(long id);
        /// <summary>
        /// modified a T element with an id
        /// </summary>
        /// <param name="id">the id of the T element</param>
        /// <param name="answer">an answer that contains all modified properties</param>
        /// <returns>
        /// the T element (modified) that corresponde
        /// to the id or null if there isn't any
        /// </returns>
        public T? modifierAnswer(long id, T answer);
        /// <summary>
        /// delete a T element with an id
        /// </summary>
        /// <param name="id">the id of the T element</param>
        /// <returns>
        /// the T element deleted that corresponde
        /// to the id or null if there isn't any
        /// </returns>
        public T? supprimerAnswer(long id);
        /// <summary>
        /// add a T element
        /// </summary>
        /// <param name="answer">the answer to add</param>
        /// <returns>
        /// the T element (modified) that corresponde
        /// to the id or null if there isn't any
        /// </returns>
        public T ajouterAnswer(T answer);
    }
}
